@@ -1,6 +1,5 @@
-
 /*
- * $Id$
+ * DEBUG: section 93    eCAP Interface
  */
 
 #ifndef SQUID_ECAP_SERVICE_REP_H
@@ -13,7 +12,8 @@
 
 namespace Adaptation
 {
-namespace Ecap {
+namespace Ecap
+{
 
 /* The eCAP service representative maintains information about a single eCAP
    service that Squid communicates with. One eCAP module may register many
@@ -22,34 +22,41 @@ namespace Ecap {
 class ServiceRep : public Adaptation::Service
 {
 public:
-    ServiceRep(const Adaptation::ServiceConfig &config);
+    explicit ServiceRep(const ServiceConfigPointer &aConfig);
     virtual ~ServiceRep();
 
     typedef libecap::shared_ptr<libecap::adapter::Service> AdapterService;
-    void noteService(const AdapterService &s);
 
+    /* Adaptation::Service API */
     virtual void finalize();
-
-    // call when the service is no longer needed or valid
-    virtual void invalidate();
-
     virtual bool probed() const;
     virtual bool up() const;
-
-    Adaptation::Initiate *makeXactLauncher(Adaptation::Initiator *, HttpMsg *virginHeader, HttpRequest *virginCause);
-
-    // the methods below can only be called on an up() service
+    virtual Adaptation::Initiate *makeXactLauncher(HttpMsg *virginHeader, HttpRequest *virginCause);
     virtual bool wantsUrl(const String &urlPath) const;
-
-    // called by transactions to report service failure
     virtual void noteFailure();
-
     virtual const char *status() const;
+    virtual void detach();
+    virtual bool detached() const;
+
+protected:
+    void tryConfigureAndStart();
+    bool handleFinalizeFailure(const char *error);
 
 private:
     AdapterService theService; // the actual adaptation service we represent
+    bool           isDetached;
 };
 
+/// register loaded eCAP module service
+void RegisterAdapterService(const ServiceRep::AdapterService& adapterService);
+/// unregister loaded eCAP module service by service uri
+void UnregisterAdapterService(const String& serviceUri);
+
+/// returns loaded eCAP module service by service uri
+ServiceRep::AdapterService FindAdapterService(const String& serviceUri);
+
+/// check for loaded eCAP services without matching ecap_service in squid.conf
+void CheckUnusedAdapterServices(const Services& services);
 } // namespace Ecap
 } // namespace Adaptation
 
